@@ -32,14 +32,20 @@
 
 
 MarkdownPart::MarkdownPart(QWidget* parentWidget, QObject* parent, const KPluginMetaData& metaData, Modus modus)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     : KParts::ReadOnlyPart(parent)
+#else
+    : KParts::ReadOnlyPart(parent, metaData)
+#endif
     , m_sourceDocument(new QTextDocument(this))
     , m_widget(new MarkdownView(m_sourceDocument, parentWidget))
     , m_searchToolBar(new SearchToolBar(m_widget, parentWidget))
     , m_browserExtension(new MarkdownBrowserExtension(this))
 {
     // set component data
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     setMetaData(metaData);
+#endif
 
     // set internal UI
     auto* mainLayout = new QVBoxLayout;
@@ -336,3 +342,5 @@ QUrl MarkdownPart::resolvedUrl(const QUrl &url) const
 
     return (u.adjusted(QUrl::NormalizePathSegments));
 }
+
+#include "moc_markdownpart.cpp"
